AudioMidiShell

Struct AudioMidiShell 

pub struct AudioMidiShell {
    pub midi_connections: Vec<MidiInputConnection<Sender<(u64, Vec<u8>)>>>,
    pub output_device: OutputDevice,
}
Shell running the audio and MIDI processing.

Fields

midi_connections: Vec<MidiInputConnection<Sender<(u64, Vec<u8>)>>>

MIDI connections.

output_device: OutputDevice

Output device:

Implementations

Source

impl AudioMidiShell

pub fn spawn( sample_rate: u32, buffer_size: usize, process_chunk_size: usize, generator: impl AudioGenerator + Send + 'static, ) -> Self

Initializes the MIDI inputs, the output device and runs the generator in a callback. It returns a shell object that must be kept alive.

  • sample_rate is the sampling frequency in Hz.
  • buffer_size is the number of frames used by the system buffer. This setting determines the latency.
  • process_chunk_size is the number of frames passed to the process function.
pub fn run_forever( sample_rate: u32, buffer_size: usize, process_chunk_size: usize, generator: impl AudioGenerator + Send + 'static, ) -> !

Spawns the shell and keeps it alive forever.

  • sample_rate is the sampling frequency in Hz.
  • buffer_size is the number of samples used by the system buffer. This setting determines the latency.
  • process_chunk_size is the number of samples passed to the process function.
Examples found in repository?
examples/sine_synth.rs (lines 10-15)
9fn main() -> ! {
10    AudioMidiShell::run_forever(
11        SAMPLE_RATE,
12        BUFFER_SIZE,
13        PROCESS_CHUNK_SIZE,
14        SineSynth::default(),
15    );
16}